Class: Aws::TranscribeService::Types::CreateLanguageModelResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::TranscribeService::Types::CreateLanguageModelResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-transcribeservice/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#base_model_name ⇒ String
The Amazon Transcribe standard language model, or base model, you specified when creating your custom language model.
-
#input_data_config ⇒ Types::InputDataConfig
Lists your data access role ARN (Amazon Resource Name) and the Amazon S3 locations you provided for your training (
S3Uri) and tuning (TuningDataS3Uri) data. -
#language_code ⇒ String
The language code you selected for your custom language model.
-
#model_name ⇒ String
The name of your custom language model.
-
#model_status ⇒ String
The status of your custom language model.
Instance Attribute Details
#base_model_name ⇒ String
The Amazon Transcribe standard language model, or base model, you specified when creating your custom language model.
904 905 906 907 908 909 910 911 912 |
# File 'lib/aws-sdk-transcribeservice/types.rb', line 904 class CreateLanguageModelResponse < Struct.new( :language_code, :base_model_name, :model_name, :input_data_config, :model_status) SENSITIVE = [] include Aws::Structure end |
#input_data_config ⇒ Types::InputDataConfig
Lists your data access role ARN (Amazon Resource Name) and the
Amazon S3 locations you provided for your training (S3Uri) and
tuning (TuningDataS3Uri) data.
904 905 906 907 908 909 910 911 912 |
# File 'lib/aws-sdk-transcribeservice/types.rb', line 904 class CreateLanguageModelResponse < Struct.new( :language_code, :base_model_name, :model_name, :input_data_config, :model_status) SENSITIVE = [] include Aws::Structure end |
#language_code ⇒ String
The language code you selected for your custom language model.
904 905 906 907 908 909 910 911 912 |
# File 'lib/aws-sdk-transcribeservice/types.rb', line 904 class CreateLanguageModelResponse < Struct.new( :language_code, :base_model_name, :model_name, :input_data_config, :model_status) SENSITIVE = [] include Aws::Structure end |
#model_name ⇒ String
The name of your custom language model.
904 905 906 907 908 909 910 911 912 |
# File 'lib/aws-sdk-transcribeservice/types.rb', line 904 class CreateLanguageModelResponse < Struct.new( :language_code, :base_model_name, :model_name, :input_data_config, :model_status) SENSITIVE = [] include Aws::Structure end |
#model_status ⇒ String
The status of your custom language model. When the status displays
as COMPLETED, your model is ready to use.
904 905 906 907 908 909 910 911 912 |
# File 'lib/aws-sdk-transcribeservice/types.rb', line 904 class CreateLanguageModelResponse < Struct.new( :language_code, :base_model_name, :model_name, :input_data_config, :model_status) SENSITIVE = [] include Aws::Structure end |