Class: Aws::TranscribeService::Types::GetVocabularyResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-transcribeservice/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#data_access_role_arnString

The Amazon Resource Name (ARN) of the IAM role used to access the Amazon S3 bucket that contains your input files and, if applicable, the KMS key specified in EncryptionConfiguration.

Returns:

  • (String)


1822
1823
1824
1825
1826
1827
1828
1829
1830
1831
1832
1833
# File 'lib/aws-sdk-transcribeservice/types.rb', line 1822

class GetVocabularyResponse < Struct.new(
  :vocabulary_name,
  :language_code,
  :vocabulary_state,
  :last_modified_time,
  :failure_reason,
  :download_uri,
  :data_access_role_arn,
  :encryption_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#download_uriString

The Amazon S3 location where the custom vocabulary is stored; use this URI to view or download the custom vocabulary.

Returns:

  • (String)


1822
1823
1824
1825
1826
1827
1828
1829
1830
1831
1832
1833
# File 'lib/aws-sdk-transcribeservice/types.rb', line 1822

class GetVocabularyResponse < Struct.new(
  :vocabulary_name,
  :language_code,
  :vocabulary_state,
  :last_modified_time,
  :failure_reason,
  :download_uri,
  :data_access_role_arn,
  :encryption_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#encryption_configurationTypes::EncryptionConfiguration

The encryption configuration used for your custom vocabulary.



1822
1823
1824
1825
1826
1827
1828
1829
1830
1831
1832
1833
# File 'lib/aws-sdk-transcribeservice/types.rb', line 1822

class GetVocabularyResponse < Struct.new(
  :vocabulary_name,
  :language_code,
  :vocabulary_state,
  :last_modified_time,
  :failure_reason,
  :download_uri,
  :data_access_role_arn,
  :encryption_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#failure_reasonString

If VocabularyState is FAILED, FailureReason contains information about why the custom vocabulary request failed. See also: Common Errors.

Returns:

  • (String)


1822
1823
1824
1825
1826
1827
1828
1829
1830
1831
1832
1833
# File 'lib/aws-sdk-transcribeservice/types.rb', line 1822

class GetVocabularyResponse < Struct.new(
  :vocabulary_name,
  :language_code,
  :vocabulary_state,
  :last_modified_time,
  :failure_reason,
  :download_uri,
  :data_access_role_arn,
  :encryption_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#language_codeString

The language code you selected for your custom vocabulary.

Returns:

  • (String)


1822
1823
1824
1825
1826
1827
1828
1829
1830
1831
1832
1833
# File 'lib/aws-sdk-transcribeservice/types.rb', line 1822

class GetVocabularyResponse < Struct.new(
  :vocabulary_name,
  :language_code,
  :vocabulary_state,
  :last_modified_time,
  :failure_reason,
  :download_uri,
  :data_access_role_arn,
  :encryption_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#last_modified_timeTime

The date and time the specified custom vocabulary was last modified.

Timestamps are in the format YYYY-MM-DD'T'HH:MM:SS.SSSSSS-UTC. For example, 2022-05-04T12:32:58.761000-07:00 represents 12:32 PM UTC-7 on May 4, 2022.

Returns:

  • (Time)


1822
1823
1824
1825
1826
1827
1828
1829
1830
1831
1832
1833
# File 'lib/aws-sdk-transcribeservice/types.rb', line 1822

class GetVocabularyResponse < Struct.new(
  :vocabulary_name,
  :language_code,
  :vocabulary_state,
  :last_modified_time,
  :failure_reason,
  :download_uri,
  :data_access_role_arn,
  :encryption_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#vocabulary_nameString

The name of the custom vocabulary you requested information about.

Returns:

  • (String)


1822
1823
1824
1825
1826
1827
1828
1829
1830
1831
1832
1833
# File 'lib/aws-sdk-transcribeservice/types.rb', line 1822

class GetVocabularyResponse < Struct.new(
  :vocabulary_name,
  :language_code,
  :vocabulary_state,
  :last_modified_time,
  :failure_reason,
  :download_uri,
  :data_access_role_arn,
  :encryption_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#vocabulary_stateString

The processing state of your custom vocabulary. If the state is READY, you can use the custom vocabulary in a StartTranscriptionJob request.

Returns:

  • (String)


1822
1823
1824
1825
1826
1827
1828
1829
1830
1831
1832
1833
# File 'lib/aws-sdk-transcribeservice/types.rb', line 1822

class GetVocabularyResponse < Struct.new(
  :vocabulary_name,
  :language_code,
  :vocabulary_state,
  :last_modified_time,
  :failure_reason,
  :download_uri,
  :data_access_role_arn,
  :encryption_configuration)
  SENSITIVE = []
  include Aws::Structure
end