Class: Aws::TranscribeService::Types::InputDataConfig
- Inherits:
-
Struct
- Object
- Struct
- Aws::TranscribeService::Types::InputDataConfig
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-transcribeservice/types.rb
Overview
Contains the Amazon S3 location of the training data you want to use to create a new custom language model, and permissions to access this location.
When using InputDataConfig, you must include these sub-parameters:
S3Uri and DataAccessRoleArn. You can optionally include
TuningDataS3Uri.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#data_access_role_arn ⇒ String
The Amazon Resource Name (ARN) of an IAM role that has permissions to access the Amazon S3 bucket that contains your input files.
-
#s3_uri ⇒ String
The Amazon S3 location (URI) of the text files you want to use to train your custom language model.
-
#tuning_data_s3_uri ⇒ String
The Amazon S3 location (URI) of the text files you want to use to tune your custom language model.
Instance Attribute Details
#data_access_role_arn ⇒ String
The Amazon Resource Name (ARN) of an IAM role that has permissions to access the Amazon S3 bucket that contains your input files. If the role that you specify doesn’t have the appropriate permissions to access the specified Amazon S3 location, your request fails.
IAM role ARNs have the format
arn:partition:iam::account:role/role-name-with-path. For example:
arn:aws:iam::111122223333:role/Admin.
For more information, see IAM ARNs.
1878 1879 1880 1881 1882 1883 1884 |
# File 'lib/aws-sdk-transcribeservice/types.rb', line 1878 class InputDataConfig < Struct.new( :s3_uri, :tuning_data_s3_uri, :data_access_role_arn) SENSITIVE = [] include Aws::Structure end |
#s3_uri ⇒ String
The Amazon S3 location (URI) of the text files you want to use to train your custom language model.
Here's an example URI path:
s3://DOC-EXAMPLE-BUCKET/my-model-training-data/
1878 1879 1880 1881 1882 1883 1884 |
# File 'lib/aws-sdk-transcribeservice/types.rb', line 1878 class InputDataConfig < Struct.new( :s3_uri, :tuning_data_s3_uri, :data_access_role_arn) SENSITIVE = [] include Aws::Structure end |
#tuning_data_s3_uri ⇒ String
The Amazon S3 location (URI) of the text files you want to use to tune your custom language model.
Here's an example URI path:
s3://DOC-EXAMPLE-BUCKET/my-model-tuning-data/
1878 1879 1880 1881 1882 1883 1884 |
# File 'lib/aws-sdk-transcribeservice/types.rb', line 1878 class InputDataConfig < Struct.new( :s3_uri, :tuning_data_s3_uri, :data_access_role_arn) SENSITIVE = [] include Aws::Structure end |