Class: Aws::TranscribeService::Types::JobExecutionSettings
- Inherits:
-
Struct
- Object
- Struct
- Aws::TranscribeService::Types::JobExecutionSettings
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-transcribeservice/types.rb
Overview
Makes it possible to control how your transcription job is processed.
Currently, the only JobExecutionSettings modification you can choose
is enabling job queueing using the AllowDeferredExecution
sub-parameter.
If you include JobExecutionSettings in your request, you must also
include the sub-parameters: AllowDeferredExecution and
DataAccessRoleArn.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#allow_deferred_execution ⇒ Boolean
Makes it possible to enable job queuing when your concurrent request limit is exceeded.
-
#data_access_role_arn ⇒ String
The Amazon Resource Name (ARN) of an IAM role that has permissions to access the Amazon S3 bucket that contains your input files.
Instance Attribute Details
#allow_deferred_execution ⇒ Boolean
Makes it possible to enable job queuing when your concurrent request
limit is exceeded. When AllowDeferredExecution is set to true,
transcription job requests are placed in a queue until the number of
jobs falls below the concurrent request limit. If
AllowDeferredExecution is set to false and the number of
transcription job requests exceed the concurrent request limit, you
get a LimitExceededException error.
If you include AllowDeferredExecution in your request, you must
also include DataAccessRoleArn.
2002 2003 2004 2005 2006 2007 |
# File 'lib/aws-sdk-transcribeservice/types.rb', line 2002 class JobExecutionSettings < Struct.new( :allow_deferred_execution, :data_access_role_arn) SENSITIVE = [] include Aws::Structure end |
#data_access_role_arn ⇒ String
The Amazon Resource Name (ARN) of an IAM role that has permissions to access the Amazon S3 bucket that contains your input files. If the role that you specify doesn’t have the appropriate permissions to access the specified Amazon S3 location, your request fails.
IAM role ARNs have the format
arn:partition:iam::account:role/role-name-with-path. For example:
arn:aws:iam::111122223333:role/Admin. For more information, see
IAM ARNs.
Note that if you include DataAccessRoleArn in your request, you
must also include AllowDeferredExecution.
2002 2003 2004 2005 2006 2007 |
# File 'lib/aws-sdk-transcribeservice/types.rb', line 2002 class JobExecutionSettings < Struct.new( :allow_deferred_execution, :data_access_role_arn) SENSITIVE = [] include Aws::Structure end |