Class: Aws::TranscribeService::Types::ListCallAnalyticsJobsResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-transcribeservice/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#call_analytics_job_summariesArray<Types::CallAnalyticsJobSummary>

Provides a summary of information about each result.

Returns:



2351
2352
2353
2354
2355
2356
2357
# File 'lib/aws-sdk-transcribeservice/types.rb', line 2351

class ListCallAnalyticsJobsResponse < Struct.new(
  :status,
  :next_token,
  :call_analytics_job_summaries)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

If NextToken is present in your response, it indicates that not all results are displayed. To view the next set of results, copy the string associated with the NextToken parameter in your results output, then run your request again including NextToken with the value of the copied string. Repeat as needed to view all your results.

Returns:



2351
2352
2353
2354
2355
2356
2357
# File 'lib/aws-sdk-transcribeservice/types.rb', line 2351

class ListCallAnalyticsJobsResponse < Struct.new(
  :status,
  :next_token,
  :call_analytics_job_summaries)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

Lists all Call Analytics jobs that have the status specified in your request. Jobs are ordered by creation date, with the newest job first.

Returns:



2351
2352
2353
2354
2355
2356
2357
# File 'lib/aws-sdk-transcribeservice/types.rb', line 2351

class ListCallAnalyticsJobsResponse < Struct.new(
  :status,
  :next_token,
  :call_analytics_job_summaries)
  SENSITIVE = []
  include Aws::Structure
end