Class: Aws::TranscribeService::Types::ListLanguageModelsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-transcribeservice/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#max_resultsInteger

The maximum number of custom language models to return in each page of results. If there are fewer results than the value that you specify, only the actual results are returned. If you do not specify a value, a default of 5 is used.

Returns:



2388
2389
2390
2391
2392
2393
2394
2395
# File 'lib/aws-sdk-transcribeservice/types.rb', line 2388

class ListLanguageModelsRequest < Struct.new(
  :status_equals,
  :name_contains,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#name_containsString

Returns only the custom language models that contain the specified string. The search is not case sensitive.

Returns:



2388
2389
2390
2391
2392
2393
2394
2395
# File 'lib/aws-sdk-transcribeservice/types.rb', line 2388

class ListLanguageModelsRequest < Struct.new(
  :status_equals,
  :name_contains,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

If your ListLanguageModels request returns more results than can be displayed, NextToken is displayed in the response with an associated string. To get the next page of results, copy this string and repeat your request, including NextToken with the value of the copied string. Repeat as needed to view all your results.

Returns:



2388
2389
2390
2391
2392
2393
2394
2395
# File 'lib/aws-sdk-transcribeservice/types.rb', line 2388

class ListLanguageModelsRequest < Struct.new(
  :status_equals,
  :name_contains,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#status_equalsString

Returns only custom language models with the specified status. Language models are ordered by creation date, with the newest model first. If you do not include StatusEquals, all custom language models are returned.

Returns:



2388
2389
2390
2391
2392
2393
2394
2395
# File 'lib/aws-sdk-transcribeservice/types.rb', line 2388

class ListLanguageModelsRequest < Struct.new(
  :status_equals,
  :name_contains,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end