Class: Aws::TranscribeService::Types::ListLanguageModelsResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::TranscribeService::Types::ListLanguageModelsResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-transcribeservice/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#models ⇒ Array<Types::LanguageModel>
Provides information about the custom language models that match the criteria specified in your request.
-
#next_token ⇒ String
If
NextTokenis present in your response, it indicates that not all results are displayed.
Instance Attribute Details
#models ⇒ Array<Types::LanguageModel>
Provides information about the custom language models that match the criteria specified in your request.
2413 2414 2415 2416 2417 2418 |
# File 'lib/aws-sdk-transcribeservice/types.rb', line 2413 class ListLanguageModelsResponse < Struct.new( :next_token, :models) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
If NextToken is present in your response, it indicates that not
all results are displayed. To view the next set of results, copy the
string associated with the NextToken parameter in your results
output, then run your request again including NextToken with the
value of the copied string. Repeat as needed to view all your
results.
2413 2414 2415 2416 2417 2418 |
# File 'lib/aws-sdk-transcribeservice/types.rb', line 2413 class ListLanguageModelsResponse < Struct.new( :next_token, :models) SENSITIVE = [] include Aws::Structure end |