Class: Aws::TranscribeService::Types::ListMedicalScribeJobsResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::TranscribeService::Types::ListMedicalScribeJobsResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-transcribeservice/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#medical_scribe_job_summaries ⇒ Array<Types::MedicalScribeJobSummary>
Provides a summary of information about each result.
-
#next_token ⇒ String
If
NextTokenis present in your response, it indicates that not all results are displayed. -
#status ⇒ String
Lists all Medical Scribe jobs that have the status specified in your request.
Instance Attribute Details
#medical_scribe_job_summaries ⇒ Array<Types::MedicalScribeJobSummary>
Provides a summary of information about each result.
2478 2479 2480 2481 2482 2483 2484 |
# File 'lib/aws-sdk-transcribeservice/types.rb', line 2478 class ListMedicalScribeJobsResponse < Struct.new( :status, :next_token, :medical_scribe_job_summaries) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
If NextToken is present in your response, it indicates that not
all results are displayed. To view the next set of results, copy the
string associated with the NextToken parameter in your results
output, then run your request again including NextToken with the
value of the copied string. Repeat as needed to view all your
results.
2478 2479 2480 2481 2482 2483 2484 |
# File 'lib/aws-sdk-transcribeservice/types.rb', line 2478 class ListMedicalScribeJobsResponse < Struct.new( :status, :next_token, :medical_scribe_job_summaries) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
Lists all Medical Scribe jobs that have the status specified in your request. Jobs are ordered by creation date, with the newest job first.
2478 2479 2480 2481 2482 2483 2484 |
# File 'lib/aws-sdk-transcribeservice/types.rb', line 2478 class ListMedicalScribeJobsResponse < Struct.new( :status, :next_token, :medical_scribe_job_summaries) SENSITIVE = [] include Aws::Structure end |