Class: Aws::TranscribeService::Types::ListMedicalVocabulariesRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::TranscribeService::Types::ListMedicalVocabulariesRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-transcribeservice/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#max_results ⇒ Integer
The maximum number of custom medical vocabularies to return in each page of results.
-
#name_contains ⇒ String
Returns only the custom medical vocabularies that contain the specified string.
-
#next_token ⇒ String
If your
ListMedicalVocabulariesrequest returns more results than can be displayed,NextTokenis displayed in the response with an associated string. -
#state_equals ⇒ String
Returns only custom medical vocabularies with the specified state.
Instance Attribute Details
#max_results ⇒ Integer
The maximum number of custom medical vocabularies to return in each page of results. If there are fewer results than the value that you specify, only the actual results are returned. If you do not specify a value, a default of 5 is used.
2582 2583 2584 2585 2586 2587 2588 2589 |
# File 'lib/aws-sdk-transcribeservice/types.rb', line 2582 class ListMedicalVocabulariesRequest < Struct.new( :next_token, :max_results, :state_equals, :name_contains) SENSITIVE = [] include Aws::Structure end |
#name_contains ⇒ String
Returns only the custom medical vocabularies that contain the specified string. The search is not case sensitive.
2582 2583 2584 2585 2586 2587 2588 2589 |
# File 'lib/aws-sdk-transcribeservice/types.rb', line 2582 class ListMedicalVocabulariesRequest < Struct.new( :next_token, :max_results, :state_equals, :name_contains) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
If your ListMedicalVocabularies request returns more results than
can be displayed, NextToken is displayed in the response with an
associated string. To get the next page of results, copy this string
and repeat your request, including NextToken with the value of the
copied string. Repeat as needed to view all your results.
2582 2583 2584 2585 2586 2587 2588 2589 |
# File 'lib/aws-sdk-transcribeservice/types.rb', line 2582 class ListMedicalVocabulariesRequest < Struct.new( :next_token, :max_results, :state_equals, :name_contains) SENSITIVE = [] include Aws::Structure end |
#state_equals ⇒ String
Returns only custom medical vocabularies with the specified state.
Custom vocabularies are ordered by creation date, with the newest
vocabulary first. If you do not include StateEquals, all custom
medical vocabularies are returned.
2582 2583 2584 2585 2586 2587 2588 2589 |
# File 'lib/aws-sdk-transcribeservice/types.rb', line 2582 class ListMedicalVocabulariesRequest < Struct.new( :next_token, :max_results, :state_equals, :name_contains) SENSITIVE = [] include Aws::Structure end |