Class: Aws::TranscribeService::Types::ListTranscriptionJobsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-transcribeservice/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#job_name_containsString

Returns only the transcription jobs that contain the specified string. The search is not case sensitive.

Returns:



2688
2689
2690
2691
2692
2693
2694
2695
# File 'lib/aws-sdk-transcribeservice/types.rb', line 2688

class ListTranscriptionJobsRequest < Struct.new(
  :status,
  :job_name_contains,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of transcription jobs to return in each page of results. If there are fewer results than the value that you specify, only the actual results are returned. If you do not specify a value, a default of 5 is used.

Returns:



2688
2689
2690
2691
2692
2693
2694
2695
# File 'lib/aws-sdk-transcribeservice/types.rb', line 2688

class ListTranscriptionJobsRequest < Struct.new(
  :status,
  :job_name_contains,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

If your ListTranscriptionJobs request returns more results than can be displayed, NextToken is displayed in the response with an associated string. To get the next page of results, copy this string and repeat your request, including NextToken with the value of the copied string. Repeat as needed to view all your results.

Returns:



2688
2689
2690
2691
2692
2693
2694
2695
# File 'lib/aws-sdk-transcribeservice/types.rb', line 2688

class ListTranscriptionJobsRequest < Struct.new(
  :status,
  :job_name_contains,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

Returns only transcription jobs with the specified status. Jobs are ordered by creation date, with the newest job first. If you do not include Status, all transcription jobs are returned.

Returns:



2688
2689
2690
2691
2692
2693
2694
2695
# File 'lib/aws-sdk-transcribeservice/types.rb', line 2688

class ListTranscriptionJobsRequest < Struct.new(
  :status,
  :job_name_contains,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end