Class: Aws::TranscribeService::Types::ListTranscriptionJobsResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-transcribeservice/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#next_tokenString

If NextToken is present in your response, it indicates that not all results are displayed. To view the next set of results, copy the string associated with the NextToken parameter in your results output, then run your request again including NextToken with the value of the copied string. Repeat as needed to view all your results.

Returns:

  • (String)


2718
2719
2720
2721
2722
2723
2724
# File 'lib/aws-sdk-transcribeservice/types.rb', line 2718

class ListTranscriptionJobsResponse < Struct.new(
  :status,
  :next_token,
  :transcription_job_summaries)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

Lists all transcription jobs that have the status specified in your request. Jobs are ordered by creation date, with the newest job first.

Returns:

  • (String)


2718
2719
2720
2721
2722
2723
2724
# File 'lib/aws-sdk-transcribeservice/types.rb', line 2718

class ListTranscriptionJobsResponse < Struct.new(
  :status,
  :next_token,
  :transcription_job_summaries)
  SENSITIVE = []
  include Aws::Structure
end

#transcription_job_summariesArray<Types::TranscriptionJobSummary>

Provides a summary of information about each result.

Returns:



2718
2719
2720
2721
2722
2723
2724
# File 'lib/aws-sdk-transcribeservice/types.rb', line 2718

class ListTranscriptionJobsResponse < Struct.new(
  :status,
  :next_token,
  :transcription_job_summaries)
  SENSITIVE = []
  include Aws::Structure
end