Class: Aws::TranscribeService::Types::ListVocabulariesResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-transcribeservice/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#next_tokenString

If NextToken is present in your response, it indicates that not all results are displayed. To view the next set of results, copy the string associated with the NextToken parameter in your results output, then run your request again including NextToken with the value of the copied string. Repeat as needed to view all your results.

Returns:

  • (String)


2786
2787
2788
2789
2790
2791
2792
# File 'lib/aws-sdk-transcribeservice/types.rb', line 2786

class ListVocabulariesResponse < Struct.new(
  :status,
  :next_token,
  :vocabularies)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

Lists all custom vocabularies that have the status specified in your request. Vocabularies are ordered by creation date, with the newest vocabulary first.

Returns:

  • (String)


2786
2787
2788
2789
2790
2791
2792
# File 'lib/aws-sdk-transcribeservice/types.rb', line 2786

class ListVocabulariesResponse < Struct.new(
  :status,
  :next_token,
  :vocabularies)
  SENSITIVE = []
  include Aws::Structure
end

#vocabulariesArray<Types::VocabularyInfo>

Provides information about the custom vocabularies that match the criteria specified in your request.

Returns:



2786
2787
2788
2789
2790
2791
2792
# File 'lib/aws-sdk-transcribeservice/types.rb', line 2786

class ListVocabulariesResponse < Struct.new(
  :status,
  :next_token,
  :vocabularies)
  SENSITIVE = []
  include Aws::Structure
end