Class: Aws::TranscribeService::Types::MedicalScribeJobSummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::TranscribeService::Types::MedicalScribeJobSummary
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-transcribeservice/types.rb
Overview
Provides detailed information about a specific Medical Scribe job.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#completion_time ⇒ Time
The date and time the specified Medical Scribe job finished processing.
-
#creation_time ⇒ Time
The date and time the specified Medical Scribe job request was made.
-
#failure_reason ⇒ String
If
MedicalScribeJobStatusisFAILED,FailureReasoncontains information about why the transcription job failed. -
#language_code ⇒ String
The language code used to create your Medical Scribe job.
-
#medical_scribe_job_name ⇒ String
The name of the Medical Scribe job.
-
#medical_scribe_job_status ⇒ String
Provides the status of the specified Medical Scribe job.
-
#start_time ⇒ Time
The date and time your Medical Scribe job began processing.
Instance Attribute Details
#completion_time ⇒ Time
The date and time the specified Medical Scribe job finished processing.
Timestamps are in the format YYYY-MM-DD'T'HH:MM:SS.SSSSSS-UTC. For
example, 2022-05-04T12:32:58.761000-07:00 represents a Medical
Scribe job that finished processing at 12:32 PM UTC-7 on May 4,
2022.
3157 3158 3159 3160 3161 3162 3163 3164 3165 3166 3167 |
# File 'lib/aws-sdk-transcribeservice/types.rb', line 3157 class MedicalScribeJobSummary < Struct.new( :medical_scribe_job_name, :creation_time, :start_time, :completion_time, :language_code, :medical_scribe_job_status, :failure_reason) SENSITIVE = [] include Aws::Structure end |
#creation_time ⇒ Time
The date and time the specified Medical Scribe job request was made.
Timestamps are in the format YYYY-MM-DD'T'HH:MM:SS.SSSSSS-UTC. For
example, 2022-05-04T12:32:58.761000-07:00 represents a Medical
Scribe job that started processing at 12:32 PM UTC-7 on May 4, 2022.
3157 3158 3159 3160 3161 3162 3163 3164 3165 3166 3167 |
# File 'lib/aws-sdk-transcribeservice/types.rb', line 3157 class MedicalScribeJobSummary < Struct.new( :medical_scribe_job_name, :creation_time, :start_time, :completion_time, :language_code, :medical_scribe_job_status, :failure_reason) SENSITIVE = [] include Aws::Structure end |
#failure_reason ⇒ String
If MedicalScribeJobStatus is FAILED, FailureReason contains
information about why the transcription job failed. See also:
Common Errors.
3157 3158 3159 3160 3161 3162 3163 3164 3165 3166 3167 |
# File 'lib/aws-sdk-transcribeservice/types.rb', line 3157 class MedicalScribeJobSummary < Struct.new( :medical_scribe_job_name, :creation_time, :start_time, :completion_time, :language_code, :medical_scribe_job_status, :failure_reason) SENSITIVE = [] include Aws::Structure end |
#language_code ⇒ String
The language code used to create your Medical Scribe job. US English
(en-US) is the only supported language for Medical Scribe jobs.
3157 3158 3159 3160 3161 3162 3163 3164 3165 3166 3167 |
# File 'lib/aws-sdk-transcribeservice/types.rb', line 3157 class MedicalScribeJobSummary < Struct.new( :medical_scribe_job_name, :creation_time, :start_time, :completion_time, :language_code, :medical_scribe_job_status, :failure_reason) SENSITIVE = [] include Aws::Structure end |
#medical_scribe_job_name ⇒ String
The name of the Medical Scribe job. Job names are case sensitive and must be unique within an Amazon Web Services account.
3157 3158 3159 3160 3161 3162 3163 3164 3165 3166 3167 |
# File 'lib/aws-sdk-transcribeservice/types.rb', line 3157 class MedicalScribeJobSummary < Struct.new( :medical_scribe_job_name, :creation_time, :start_time, :completion_time, :language_code, :medical_scribe_job_status, :failure_reason) SENSITIVE = [] include Aws::Structure end |
#medical_scribe_job_status ⇒ String
Provides the status of the specified Medical Scribe job.
If the status is COMPLETED, the job is finished and you can find
the results at the location specified in MedicalScribeOutput If
the status is FAILED, FailureReason provides details on why your
Medical Scribe job failed.
3157 3158 3159 3160 3161 3162 3163 3164 3165 3166 3167 |
# File 'lib/aws-sdk-transcribeservice/types.rb', line 3157 class MedicalScribeJobSummary < Struct.new( :medical_scribe_job_name, :creation_time, :start_time, :completion_time, :language_code, :medical_scribe_job_status, :failure_reason) SENSITIVE = [] include Aws::Structure end |
#start_time ⇒ Time
The date and time your Medical Scribe job began processing.
Timestamps are in the format YYYY-MM-DD'T'HH:MM:SS.SSSSSS-UTC. For
example, 2022-05-04T12:32:58.789000-07:00 represents a Medical
Scribe job that started processing at 12:32 PM UTC-7 on May 4, 2022.
3157 3158 3159 3160 3161 3162 3163 3164 3165 3166 3167 |
# File 'lib/aws-sdk-transcribeservice/types.rb', line 3157 class MedicalScribeJobSummary < Struct.new( :medical_scribe_job_name, :creation_time, :start_time, :completion_time, :language_code, :medical_scribe_job_status, :failure_reason) SENSITIVE = [] include Aws::Structure end |