Class: Aws::TranscribeService::Types::MedicalScribeSettings
- Inherits:
-
Struct
- Object
- Struct
- Aws::TranscribeService::Types::MedicalScribeSettings
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-transcribeservice/types.rb
Overview
Makes it possible to control how your Medical Scribe job is processed
using a MedicalScribeSettings object. Specify
ChannelIdentification if ChannelDefinitions are set. Enabled
ShowSpeakerLabels if ChannelIdentification and
ChannelDefinitions are not set. One and only one of
ChannelIdentification and ShowSpeakerLabels must be set. If
ShowSpeakerLabels is set, MaxSpeakerLabels must also be set. Use
Settings to specify a vocabulary or vocabulary filter or both using
VocabularyName, VocabularyFilterName. VocabularyFilterMethod
must be specified if VocabularyFilterName is set.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#channel_identification ⇒ Boolean
Enables channel identification in multi-channel audio.
-
#clinical_note_generation_settings ⇒ Types::ClinicalNoteGenerationSettings
Specify settings for the clinical note generation.
-
#max_speaker_labels ⇒ Integer
Specify the maximum number of speakers you want to partition in your media.
-
#show_speaker_labels ⇒ Boolean
Enables speaker partitioning (diarization) in your Medical Scribe output.
-
#vocabulary_filter_method ⇒ String
Specify how you want your custom vocabulary filter applied to your transcript.
-
#vocabulary_filter_name ⇒ String
The name of the custom vocabulary filter you want to include in your Medical Scribe request.
-
#vocabulary_name ⇒ String
The name of the custom vocabulary you want to include in your Medical Scribe request.
Instance Attribute Details
#channel_identification ⇒ Boolean
Enables channel identification in multi-channel audio.
Channel identification transcribes the audio on each channel independently, then appends the output for each channel into one transcript.
For more information, see Transcribing multi-channel audio.
3289 3290 3291 3292 3293 3294 3295 3296 3297 3298 3299 |
# File 'lib/aws-sdk-transcribeservice/types.rb', line 3289 class MedicalScribeSettings < Struct.new( :show_speaker_labels, :max_speaker_labels, :channel_identification, :vocabulary_name, :vocabulary_filter_name, :vocabulary_filter_method, :clinical_note_generation_settings) SENSITIVE = [] include Aws::Structure end |
#clinical_note_generation_settings ⇒ Types::ClinicalNoteGenerationSettings
Specify settings for the clinical note generation.
3289 3290 3291 3292 3293 3294 3295 3296 3297 3298 3299 |
# File 'lib/aws-sdk-transcribeservice/types.rb', line 3289 class MedicalScribeSettings < Struct.new( :show_speaker_labels, :max_speaker_labels, :channel_identification, :vocabulary_name, :vocabulary_filter_name, :vocabulary_filter_method, :clinical_note_generation_settings) SENSITIVE = [] include Aws::Structure end |
#max_speaker_labels ⇒ Integer
Specify the maximum number of speakers you want to partition in your media.
Note that if your media contains more speakers than the specified number, multiple speakers are treated as a single speaker.
If you specify the MaxSpeakerLabels field, you must set the
ShowSpeakerLabels field to true.
3289 3290 3291 3292 3293 3294 3295 3296 3297 3298 3299 |
# File 'lib/aws-sdk-transcribeservice/types.rb', line 3289 class MedicalScribeSettings < Struct.new( :show_speaker_labels, :max_speaker_labels, :channel_identification, :vocabulary_name, :vocabulary_filter_name, :vocabulary_filter_method, :clinical_note_generation_settings) SENSITIVE = [] include Aws::Structure end |
#show_speaker_labels ⇒ Boolean
Enables speaker partitioning (diarization) in your Medical Scribe output. Speaker partitioning labels the speech from individual speakers in your media file.
If you enable ShowSpeakerLabels in your request, you must also
include MaxSpeakerLabels.
For more information, see Partitioning speakers (diarization).
3289 3290 3291 3292 3293 3294 3295 3296 3297 3298 3299 |
# File 'lib/aws-sdk-transcribeservice/types.rb', line 3289 class MedicalScribeSettings < Struct.new( :show_speaker_labels, :max_speaker_labels, :channel_identification, :vocabulary_name, :vocabulary_filter_name, :vocabulary_filter_method, :clinical_note_generation_settings) SENSITIVE = [] include Aws::Structure end |
#vocabulary_filter_method ⇒ String
Specify how you want your custom vocabulary filter applied to your transcript.
To replace words with ***, choose mask.
To delete words, choose remove.
To flag words without changing them, choose tag.
3289 3290 3291 3292 3293 3294 3295 3296 3297 3298 3299 |
# File 'lib/aws-sdk-transcribeservice/types.rb', line 3289 class MedicalScribeSettings < Struct.new( :show_speaker_labels, :max_speaker_labels, :channel_identification, :vocabulary_name, :vocabulary_filter_name, :vocabulary_filter_method, :clinical_note_generation_settings) SENSITIVE = [] include Aws::Structure end |
#vocabulary_filter_name ⇒ String
The name of the custom vocabulary filter you want to include in your Medical Scribe request. Custom vocabulary filter names are case sensitive.
Note that if you include VocabularyFilterName in your request, you
must also include VocabularyFilterMethod.
3289 3290 3291 3292 3293 3294 3295 3296 3297 3298 3299 |
# File 'lib/aws-sdk-transcribeservice/types.rb', line 3289 class MedicalScribeSettings < Struct.new( :show_speaker_labels, :max_speaker_labels, :channel_identification, :vocabulary_name, :vocabulary_filter_name, :vocabulary_filter_method, :clinical_note_generation_settings) SENSITIVE = [] include Aws::Structure end |
#vocabulary_name ⇒ String
The name of the custom vocabulary you want to include in your Medical Scribe request. Custom vocabulary names are case sensitive.
3289 3290 3291 3292 3293 3294 3295 3296 3297 3298 3299 |
# File 'lib/aws-sdk-transcribeservice/types.rb', line 3289 class MedicalScribeSettings < Struct.new( :show_speaker_labels, :max_speaker_labels, :channel_identification, :vocabulary_name, :vocabulary_filter_name, :vocabulary_filter_method, :clinical_note_generation_settings) SENSITIVE = [] include Aws::Structure end |