Class: Aws::TranscribeService::Types::Rule

Inherits:
Struct
  • Object
show all
Includes:
Structure, Structure::Union
Defined in:
lib/aws-sdk-transcribeservice/types.rb

Overview

Note:

Rule is a union - when making an API calls you must set exactly one of the members.

Note:

Rule is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of Rule corresponding to the set member.

A rule is a set of criteria that you can specify to flag an attribute in your Call Analytics output. Rules define a Call Analytics category.

Rules can include these parameters: , , , and .

To learn more about Call Analytics rules and categories, see Creating categories for post-call transcriptions and Creating categories for real-time transcriptions.

To learn more about Call Analytics, see Analyzing call center audio with Call Analytics.

Defined Under Namespace

Classes: InterruptionFilter, NonTalkTimeFilter, SentimentFilter, TranscriptFilter, Unknown

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#interruption_filterTypes::InterruptionFilter

Flag the presence or absence of interruptions in your Call Analytics transcription output. Refer to for more detail.

Returns:



3909
3910
3911
3912
3913
3914
3915
3916
3917
3918
3919
3920
3921
3922
3923
3924
# File 'lib/aws-sdk-transcribeservice/types.rb', line 3909

class Rule < Struct.new(
  :non_talk_time_filter,
  :interruption_filter,
  :transcript_filter,
  :sentiment_filter,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class NonTalkTimeFilter < Rule; end
  class InterruptionFilter < Rule; end
  class TranscriptFilter < Rule; end
  class SentimentFilter < Rule; end
  class Unknown < Rule; end
end

#non_talk_time_filterTypes::NonTalkTimeFilter

Flag the presence or absence of periods of silence in your Call Analytics transcription output. Refer to for more detail.

Returns:



3909
3910
3911
3912
3913
3914
3915
3916
3917
3918
3919
3920
3921
3922
3923
3924
# File 'lib/aws-sdk-transcribeservice/types.rb', line 3909

class Rule < Struct.new(
  :non_talk_time_filter,
  :interruption_filter,
  :transcript_filter,
  :sentiment_filter,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class NonTalkTimeFilter < Rule; end
  class InterruptionFilter < Rule; end
  class TranscriptFilter < Rule; end
  class SentimentFilter < Rule; end
  class Unknown < Rule; end
end

#sentiment_filterTypes::SentimentFilter

Flag the presence or absence of specific sentiments in your Call Analytics transcription output. Refer to for more detail.

Returns:



3909
3910
3911
3912
3913
3914
3915
3916
3917
3918
3919
3920
3921
3922
3923
3924
# File 'lib/aws-sdk-transcribeservice/types.rb', line 3909

class Rule < Struct.new(
  :non_talk_time_filter,
  :interruption_filter,
  :transcript_filter,
  :sentiment_filter,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class NonTalkTimeFilter < Rule; end
  class InterruptionFilter < Rule; end
  class TranscriptFilter < Rule; end
  class SentimentFilter < Rule; end
  class Unknown < Rule; end
end

#transcript_filterTypes::TranscriptFilter

Flag the presence or absence of specific words or phrases in your Call Analytics transcription output. Refer to for more detail.

Returns:



3909
3910
3911
3912
3913
3914
3915
3916
3917
3918
3919
3920
3921
3922
3923
3924
# File 'lib/aws-sdk-transcribeservice/types.rb', line 3909

class Rule < Struct.new(
  :non_talk_time_filter,
  :interruption_filter,
  :transcript_filter,
  :sentiment_filter,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class NonTalkTimeFilter < Rule; end
  class InterruptionFilter < Rule; end
  class TranscriptFilter < Rule; end
  class SentimentFilter < Rule; end
  class Unknown < Rule; end
end

#unknownObject

Returns the value of attribute unknown

Returns:

  • the current value of unknown



3909
3910
3911
# File 'lib/aws-sdk-transcribeservice/types.rb', line 3909

def unknown
  @unknown
end