Class: Aws::TranscribeService::Types::StartMedicalScribeJobRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::TranscribeService::Types::StartMedicalScribeJobRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-transcribeservice/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#channel_definitions ⇒ Array<Types::MedicalScribeChannelDefinition>
Makes it possible to specify which speaker is on which channel.
-
#data_access_role_arn ⇒ String
The Amazon Resource Name (ARN) of an IAM role that has permissions to access the Amazon S3 bucket that contains your input files, write to the output bucket, and use your KMS key if supplied.
-
#kms_encryption_context ⇒ Hash<String,String>
A map of plain text, non-secret key:value pairs, known as encryption context pairs, that provide an added layer of security for your data.
-
#media ⇒ Types::Media
Describes the Amazon S3 location of the media file you want to use in your request.
-
#medical_scribe_context ⇒ Types::MedicalScribeContext
The
MedicalScribeContextobject that contains contextual information which is used during clinical note generation to add relevant context to the note. -
#medical_scribe_job_name ⇒ String
A unique name, chosen by you, for your Medical Scribe job.
-
#output_bucket_name ⇒ String
The name of the Amazon S3 bucket where you want your Medical Scribe output stored.
-
#output_encryption_kms_key_id ⇒ String
The Amazon Resource Name (ARN) of a KMS key that you want to use to encrypt your Medical Scribe output.
-
#settings ⇒ Types::MedicalScribeSettings
Makes it possible to control how your Medical Scribe job is processed using a
MedicalScribeSettingsobject. -
#tags ⇒ Array<Types::Tag>
Adds one or more custom tags, each in the form of a key:value pair, to the Medical Scribe job.
Instance Attribute Details
#channel_definitions ⇒ Array<Types::MedicalScribeChannelDefinition>
Makes it possible to specify which speaker is on which channel. For example, if the clinician is the first participant to speak, you would set ChannelId of the first ChannelDefinition in the list to 0 (to indicate the first channel) and ParticipantRole to CLINICIAN (to indicate that it’s the clinician speaking). Then you would set the ChannelId of the second ChannelDefinition in the list to 1 (to indicate the second channel) and ParticipantRole to PATIENT (to indicate that it’s the patient speaking).
4290 4291 4292 4293 4294 4295 4296 4297 4298 4299 4300 4301 4302 4303 |
# File 'lib/aws-sdk-transcribeservice/types.rb', line 4290 class StartMedicalScribeJobRequest < Struct.new( :medical_scribe_job_name, :media, :output_bucket_name, :output_encryption_kms_key_id, :kms_encryption_context, :data_access_role_arn, :settings, :channel_definitions, :tags, :medical_scribe_context) SENSITIVE = [] include Aws::Structure end |
#data_access_role_arn ⇒ String
The Amazon Resource Name (ARN) of an IAM role that has permissions to access the Amazon S3 bucket that contains your input files, write to the output bucket, and use your KMS key if supplied. If the role that you specify doesn’t have the appropriate permissions your request fails.
IAM role ARNs have the format arn:partition:iam::account:role/role-name-with-path. For example: arn:aws:iam::111122223333:role/Admin.
For more information, see [IAM ARNs].
[1]: docs.aws.amazon.com/IAM/latest/UserGuide/reference_identifiers.html#identifiers-arns
4290 4291 4292 4293 4294 4295 4296 4297 4298 4299 4300 4301 4302 4303 |
# File 'lib/aws-sdk-transcribeservice/types.rb', line 4290 class StartMedicalScribeJobRequest < Struct.new( :medical_scribe_job_name, :media, :output_bucket_name, :output_encryption_kms_key_id, :kms_encryption_context, :data_access_role_arn, :settings, :channel_definitions, :tags, :medical_scribe_context) SENSITIVE = [] include Aws::Structure end |
#kms_encryption_context ⇒ Hash<String,String>
A map of plain text, non-secret key:value pairs, known as encryption context pairs, that provide an added layer of security for your data. For more information, see [KMS encryption context] and [Asymmetric keys in KMS].
[1]: docs.aws.amazon.com/transcribe/latest/dg/key-management.html#kms-context [2]: docs.aws.amazon.com/transcribe/latest/dg/symmetric-asymmetric.html
4290 4291 4292 4293 4294 4295 4296 4297 4298 4299 4300 4301 4302 4303 |
# File 'lib/aws-sdk-transcribeservice/types.rb', line 4290 class StartMedicalScribeJobRequest < Struct.new( :medical_scribe_job_name, :media, :output_bucket_name, :output_encryption_kms_key_id, :kms_encryption_context, :data_access_role_arn, :settings, :channel_definitions, :tags, :medical_scribe_context) SENSITIVE = [] include Aws::Structure end |
#media ⇒ Types::Media
Describes the Amazon S3 location of the media file you want to use in your request.
For information on supported media formats, refer to the MediaFormat parameter or the [Media formats] section in the Amazon S3 Developer Guide.
[1]: docs.aws.amazon.com/transcribe/latest/dg/how-input.html#how-input-audio
4290 4291 4292 4293 4294 4295 4296 4297 4298 4299 4300 4301 4302 4303 |
# File 'lib/aws-sdk-transcribeservice/types.rb', line 4290 class StartMedicalScribeJobRequest < Struct.new( :medical_scribe_job_name, :media, :output_bucket_name, :output_encryption_kms_key_id, :kms_encryption_context, :data_access_role_arn, :settings, :channel_definitions, :tags, :medical_scribe_context) SENSITIVE = [] include Aws::Structure end |
#medical_scribe_context ⇒ Types::MedicalScribeContext
The MedicalScribeContext object that contains contextual information which is used during clinical note generation to add relevant context to the note.
4290 4291 4292 4293 4294 4295 4296 4297 4298 4299 4300 4301 4302 4303 |
# File 'lib/aws-sdk-transcribeservice/types.rb', line 4290 class StartMedicalScribeJobRequest < Struct.new( :medical_scribe_job_name, :media, :output_bucket_name, :output_encryption_kms_key_id, :kms_encryption_context, :data_access_role_arn, :settings, :channel_definitions, :tags, :medical_scribe_context) SENSITIVE = [] include Aws::Structure end |
#medical_scribe_job_name ⇒ String
A unique name, chosen by you, for your Medical Scribe job.
This name is case sensitive, cannot contain spaces, and must be unique within an Amazon Web Services account. If you try to create a new job with the same name as an existing job, you get a ConflictException error.
4290 4291 4292 4293 4294 4295 4296 4297 4298 4299 4300 4301 4302 4303 |
# File 'lib/aws-sdk-transcribeservice/types.rb', line 4290 class StartMedicalScribeJobRequest < Struct.new( :medical_scribe_job_name, :media, :output_bucket_name, :output_encryption_kms_key_id, :kms_encryption_context, :data_access_role_arn, :settings, :channel_definitions, :tags, :medical_scribe_context) SENSITIVE = [] include Aws::Structure end |
#output_bucket_name ⇒ String
The name of the Amazon S3 bucket where you want your Medical Scribe output stored. Do not include the S3:// prefix of the specified bucket.
Note that the role specified in the DataAccessRoleArn request parameter must have permission to use the specified location. You can change Amazon S3 permissions using the [Amazon Web Services Management Console]. See also [Permissions Required for IAM User Roles].
[1]: console.aws.amazon.com/s3 [2]: docs.aws.amazon.com/transcribe/latest/dg/security_iam_id-based-policy-examples.html#auth-role-iam-user
4290 4291 4292 4293 4294 4295 4296 4297 4298 4299 4300 4301 4302 4303 |
# File 'lib/aws-sdk-transcribeservice/types.rb', line 4290 class StartMedicalScribeJobRequest < Struct.new( :medical_scribe_job_name, :media, :output_bucket_name, :output_encryption_kms_key_id, :kms_encryption_context, :data_access_role_arn, :settings, :channel_definitions, :tags, :medical_scribe_context) SENSITIVE = [] include Aws::Structure end |
#output_encryption_kms_key_id ⇒ String
The Amazon Resource Name (ARN) of a KMS key that you want to use to encrypt your Medical Scribe output.
KMS key ARNs have the format arn:partition:kms:region:account:key/key-id. For example: arn:aws:kms:us-west-2:111122223333:key/1234abcd-12ab-34cd-56ef-1234567890ab. For more information, see [ KMS key ARNs].
If you do not specify an encryption key, your output is encrypted with the default Amazon S3 key (SSE-S3).
Note that the role making the request and the role specified in the DataAccessRoleArn request parameter (if present) must have permission to use the specified KMS key.
[1]: docs.aws.amazon.com/kms/latest/developerguide/concepts.html#key-id-key-ARN
4290 4291 4292 4293 4294 4295 4296 4297 4298 4299 4300 4301 4302 4303 |
# File 'lib/aws-sdk-transcribeservice/types.rb', line 4290 class StartMedicalScribeJobRequest < Struct.new( :medical_scribe_job_name, :media, :output_bucket_name, :output_encryption_kms_key_id, :kms_encryption_context, :data_access_role_arn, :settings, :channel_definitions, :tags, :medical_scribe_context) SENSITIVE = [] include Aws::Structure end |
#settings ⇒ Types::MedicalScribeSettings
Makes it possible to control how your Medical Scribe job is processed using a MedicalScribeSettings object. Specify ChannelIdentification if ChannelDefinitions are set. Enabled ShowSpeakerLabels if ChannelIdentification and ChannelDefinitions are not set. One and only one of ChannelIdentification and ShowSpeakerLabels must be set. If ShowSpeakerLabels is set, MaxSpeakerLabels must also be set. Use Settings to specify a vocabulary or vocabulary filter or both using VocabularyName, VocabularyFilterName. VocabularyFilterMethod must be specified if VocabularyFilterName is set.
4290 4291 4292 4293 4294 4295 4296 4297 4298 4299 4300 4301 4302 4303 |
# File 'lib/aws-sdk-transcribeservice/types.rb', line 4290 class StartMedicalScribeJobRequest < Struct.new( :medical_scribe_job_name, :media, :output_bucket_name, :output_encryption_kms_key_id, :kms_encryption_context, :data_access_role_arn, :settings, :channel_definitions, :tags, :medical_scribe_context) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
Adds one or more custom tags, each in the form of a key:value pair, to the Medical Scribe job.
To learn more about using tags with Amazon Transcribe, refer to [Tagging resources].
4290 4291 4292 4293 4294 4295 4296 4297 4298 4299 4300 4301 4302 4303 |
# File 'lib/aws-sdk-transcribeservice/types.rb', line 4290 class StartMedicalScribeJobRequest < Struct.new( :medical_scribe_job_name, :media, :output_bucket_name, :output_encryption_kms_key_id, :kms_encryption_context, :data_access_role_arn, :settings, :channel_definitions, :tags, :medical_scribe_context) SENSITIVE = [] include Aws::Structure end |