Class: Aws::TranscribeService::Types::UpdateLanguageModelResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-transcribeservice/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#last_modified_timeTime

The date and time the specified custom language model was last modified.

Returns:



5847
5848
5849
5850
5851
5852
5853
# File 'lib/aws-sdk-transcribeservice/types.rb', line 5847

class UpdateLanguageModelResponse < Struct.new(
  :model_name,
  :model_status,
  :last_modified_time)
  SENSITIVE = []
  include Aws::Structure
end

#model_nameString

The name of the custom language model that was updated.

Returns:



5847
5848
5849
5850
5851
5852
5853
# File 'lib/aws-sdk-transcribeservice/types.rb', line 5847

class UpdateLanguageModelResponse < Struct.new(
  :model_name,
  :model_status,
  :last_modified_time)
  SENSITIVE = []
  include Aws::Structure
end

#model_statusString

The status of the specified custom language model.

Returns:



5847
5848
5849
5850
5851
5852
5853
# File 'lib/aws-sdk-transcribeservice/types.rb', line 5847

class UpdateLanguageModelResponse < Struct.new(
  :model_name,
  :model_status,
  :last_modified_time)
  SENSITIVE = []
  include Aws::Structure
end