Class: Aws::TranscribeService::Waiters::CallAnalyticsJobCompleted
- Inherits:
-
Object
- Object
- Aws::TranscribeService::Waiters::CallAnalyticsJobCompleted
- Defined in:
- lib/aws-sdk-transcribeservice/waiters.rb
Instance Attribute Summary collapse
- #waiter ⇒ Object readonly private
Instance Method Summary collapse
-
#initialize(options) ⇒ CallAnalyticsJobCompleted
constructor
A new instance of CallAnalyticsJobCompleted.
-
#wait(params = {}) ⇒ Types::GetCallAnalyticsJobResponse
Returns a response object which responds to the following methods:.
Constructor Details
#initialize(options) ⇒ CallAnalyticsJobCompleted
Returns a new instance of CallAnalyticsJobCompleted.
90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 |
# File 'lib/aws-sdk-transcribeservice/waiters.rb', line 90 def initialize() @client = .fetch(:client) @waiter = Aws::Waiters::Waiter.new({ max_attempts: 180, delay: 10, poller: Aws::Waiters::Poller.new( operation_name: :get_call_analytics_job, acceptors: [ { "state" => "success", "matcher" => "path", "argument" => "call_analytics_job.call_analytics_job_status", "expected" => "COMPLETED" }, { "state" => "failure", "matcher" => "path", "argument" => "call_analytics_job.call_analytics_job_status", "expected" => "FAILED" } ] ) }.merge()) end |
Instance Attribute Details
#waiter ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
122 123 124 |
# File 'lib/aws-sdk-transcribeservice/waiters.rb', line 122 def waiter @waiter end |
Instance Method Details
#wait(params = {}) ⇒ Types::GetCallAnalyticsJobResponse
Returns a response object which responds to the following methods:
-
#call_analytics_job => Types::CallAnalyticsJob
117 118 119 |
# File 'lib/aws-sdk-transcribeservice/waiters.rb', line 117 def wait(params = {}) @waiter.wait(client: @client, params: params) end |