Class: Aws::TranscribeService::Waiters::MedicalScribeJobCompleted
- Inherits:
-
Object
- Object
- Aws::TranscribeService::Waiters::MedicalScribeJobCompleted
- Defined in:
- lib/aws-sdk-transcribeservice/waiters.rb
Instance Attribute Summary collapse
- #waiter ⇒ Object readonly private
Instance Method Summary collapse
-
#initialize(options) ⇒ MedicalScribeJobCompleted
constructor
A new instance of MedicalScribeJobCompleted.
-
#wait(params = {}) ⇒ Types::GetMedicalScribeJobResponse
Returns a response object which responds to the following methods:.
Constructor Details
#initialize(options) ⇒ MedicalScribeJobCompleted
Returns a new instance of MedicalScribeJobCompleted.
178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 |
# File 'lib/aws-sdk-transcribeservice/waiters.rb', line 178 def initialize() @client = .fetch(:client) @waiter = Aws::Waiters::Waiter.new({ max_attempts: 180, delay: 10, poller: Aws::Waiters::Poller.new( operation_name: :get_medical_scribe_job, acceptors: [ { "state" => "success", "matcher" => "path", "argument" => "medical_scribe_job.medical_scribe_job_status", "expected" => "COMPLETED" }, { "state" => "failure", "matcher" => "path", "argument" => "medical_scribe_job.medical_scribe_job_status", "expected" => "FAILED" } ] ) }.merge()) end |
Instance Attribute Details
#waiter ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
210 211 212 |
# File 'lib/aws-sdk-transcribeservice/waiters.rb', line 210 def waiter @waiter end |
Instance Method Details
#wait(params = {}) ⇒ Types::GetMedicalScribeJobResponse
Returns a response object which responds to the following methods:
-
#medical_scribe_job => Types::MedicalScribeJob
205 206 207 |
# File 'lib/aws-sdk-transcribeservice/waiters.rb', line 205 def wait(params = {}) @waiter.wait(client: @client, params: params) end |