Class: Aws::TranscribeService::Waiters::MedicalTranscriptionJobCompleted

Inherits:
Object
  • Object
show all
Defined in:
sig/waiters.rbs,
lib/aws-sdk-transcribeservice/waiters.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(options) ⇒ MedicalTranscriptionJobCompleted

Returns a new instance of MedicalTranscriptionJobCompleted.

Parameters:

  • options (Hash)

Options Hash (options):

  • :client (required, Client)
  • :max_attempts (Integer) — default: 180
  • :delay (Integer) — default: 10
  • :before_attempt (Proc)
  • :before_wait (Proc)


222
223
# File 'lib/aws-sdk-transcribeservice/waiters.rb', line 222

def initialize: (?client: Client, ?max_attempts: Integer, ?delay: Integer, ?before_attempt: Proc, ?before_wait: Proc) -> void
| (?Hash[Symbol, untyped]) -> void

Instance Attribute Details

#waiterObject (readonly)

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.



254
255
256
# File 'lib/aws-sdk-transcribeservice/waiters.rb', line 254

def waiter
  @waiter
end

Instance Method Details

#wait(params = {}) ⇒ Types::GetMedicalTranscriptionJobResponse

Returns a response object which responds to the following methods:

Options Hash (params):

  • :medical_transcription_job_name (required, String)

    The name of the medical transcription job you want information about. Job names are case sensitive.

Returns:



249
# File 'lib/aws-sdk-transcribeservice/waiters.rb', line 249

def wait: (