Class: Aws::TranscribeService::Waiters::MedicalVocabularyReady
- Inherits:
-
Object
- Object
- Aws::TranscribeService::Waiters::MedicalVocabularyReady
- Defined in:
- sig/waiters.rbs,
lib/aws-sdk-transcribeservice/waiters.rb
Instance Attribute Summary collapse
- #waiter ⇒ Object readonly private
Instance Method Summary collapse
-
#initialize(options) ⇒ MedicalVocabularyReady
constructor
A new instance of MedicalVocabularyReady.
-
#wait(params = {}) ⇒ Types::GetMedicalVocabularyResponse
Returns a response object which responds to the following methods:.
Constructor Details
#initialize(options) ⇒ MedicalVocabularyReady
Returns a new instance of MedicalVocabularyReady.
266 267 |
# File 'lib/aws-sdk-transcribeservice/waiters.rb', line 266
def initialize: (?client: Client, ?max_attempts: Integer, ?delay: Integer, ?before_attempt: Proc, ?before_wait: Proc) -> void
| (?Hash[Symbol, untyped]) -> void
|
Instance Attribute Details
#waiter ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
298 299 300 |
# File 'lib/aws-sdk-transcribeservice/waiters.rb', line 298 def waiter @waiter end |
Instance Method Details
#wait(params = {}) ⇒ Types::GetMedicalVocabularyResponse
Returns a response object which responds to the following methods:
- #vocabulary_name => String
- #language_code => String
- #vocabulary_state => String
- #last_modified_time => Time
- #failure_reason => String
- #download_uri => String
293 |
# File 'lib/aws-sdk-transcribeservice/waiters.rb', line 293
def wait: (
|