Class: Aws::TranscribeService::Waiters::TranscriptionJobCompleted
- Inherits:
-
Object
- Object
- Aws::TranscribeService::Waiters::TranscriptionJobCompleted
- Defined in:
- lib/aws-sdk-transcribeservice/waiters.rb
Instance Attribute Summary collapse
- #waiter ⇒ Object readonly private
Instance Method Summary collapse
-
#initialize(options) ⇒ TranscriptionJobCompleted
constructor
A new instance of TranscriptionJobCompleted.
-
#wait(params = {}) ⇒ Types::GetTranscriptionJobResponse
Returns a response object which responds to the following methods:.
Constructor Details
#initialize(options) ⇒ TranscriptionJobCompleted
Returns a new instance of TranscriptionJobCompleted.
310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 |
# File 'lib/aws-sdk-transcribeservice/waiters.rb', line 310 def initialize() @client = .fetch(:client) @waiter = Aws::Waiters::Waiter.new({ max_attempts: 180, delay: 10, poller: Aws::Waiters::Poller.new( operation_name: :get_transcription_job, acceptors: [ { "state" => "success", "matcher" => "path", "argument" => "transcription_job.transcription_job_status", "expected" => "COMPLETED" }, { "state" => "failure", "matcher" => "path", "argument" => "transcription_job.transcription_job_status", "expected" => "FAILED" } ] ) }.merge()) end |
Instance Attribute Details
#waiter ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
342 343 344 |
# File 'lib/aws-sdk-transcribeservice/waiters.rb', line 342 def waiter @waiter end |
Instance Method Details
#wait(params = {}) ⇒ Types::GetTranscriptionJobResponse
Returns a response object which responds to the following methods:
-
#transcription_job => Types::TranscriptionJob
337 338 339 |
# File 'lib/aws-sdk-transcribeservice/waiters.rb', line 337 def wait(params = {}) @waiter.wait(client: @client, params: params) end |