Class: Aws::TranscribeService::Types::CreateVocabularyRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::TranscribeService::Types::CreateVocabularyRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-transcribeservice/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#data_access_role_arn ⇒ String
The Amazon Resource Name (ARN) of an IAM role that has permissions to access the Amazon S3 bucket that contains your input files (in this case, your custom vocabulary).
-
#encryption_configuration ⇒ Types::EncryptionConfiguration
Specifies the encryption configuration for your custom vocabulary.
-
#language_code ⇒ String
The language code that represents the language of the entries in your custom vocabulary.
-
#phrases ⇒ Array<String>
Use this parameter if you want to create your custom vocabulary by including all desired terms, as comma-separated values, within your request.
-
#tags ⇒ Array<Types::Tag>
Adds one or more custom tags, each in the form of a key:value pair, to a new custom vocabulary at the time you create this new custom vocabulary.
-
#vocabulary_file_uri ⇒ String
The Amazon S3 location of the text file that contains your custom vocabulary.
-
#vocabulary_name ⇒ String
A unique name, chosen by you, for your new custom vocabulary.
Instance Attribute Details
#data_access_role_arn ⇒ String
The Amazon Resource Name (ARN) of an IAM role that has permissions
to access the Amazon S3 bucket that contains your input files (in
this case, your custom vocabulary). If you include
EncryptionConfiguration in your request, this role must also have
permissions to access the specified KMS key. If the role that you
specify doesn’t have the appropriate permissions, your request
fails.
IAM role ARNs have the format
arn:partition:iam::account:role/role-name-with-path. For example:
arn:aws:iam::111122223333:role/Admin.
For more information, see IAM ARNs.
1251 1252 1253 1254 1255 1256 1257 1258 1259 1260 1261 |
# File 'lib/aws-sdk-transcribeservice/types.rb', line 1251 class CreateVocabularyRequest < Struct.new( :vocabulary_name, :language_code, :phrases, :vocabulary_file_uri, :tags, :data_access_role_arn, :encryption_configuration) SENSITIVE = [] include Aws::Structure end |
#encryption_configuration ⇒ Types::EncryptionConfiguration
Specifies the encryption configuration for your custom vocabulary. Your vocabulary artifacts are encrypted with the specified KMS key or with an AWS-owned key if a key is not supplied.
1251 1252 1253 1254 1255 1256 1257 1258 1259 1260 1261 |
# File 'lib/aws-sdk-transcribeservice/types.rb', line 1251 class CreateVocabularyRequest < Struct.new( :vocabulary_name, :language_code, :phrases, :vocabulary_file_uri, :tags, :data_access_role_arn, :encryption_configuration) SENSITIVE = [] include Aws::Structure end |
#language_code ⇒ String
The language code that represents the language of the entries in your custom vocabulary. Each custom vocabulary must contain terms in only one language.
A custom vocabulary can only be used to transcribe files in the same
language as the custom vocabulary. For example, if you create a
custom vocabulary using US English (en-US), you can only apply
this custom vocabulary to files that contain English audio.
For a list of supported languages and their associated language codes, refer to the Supported languages table.
1251 1252 1253 1254 1255 1256 1257 1258 1259 1260 1261 |
# File 'lib/aws-sdk-transcribeservice/types.rb', line 1251 class CreateVocabularyRequest < Struct.new( :vocabulary_name, :language_code, :phrases, :vocabulary_file_uri, :tags, :data_access_role_arn, :encryption_configuration) SENSITIVE = [] include Aws::Structure end |
#phrases ⇒ Array<String>
Use this parameter if you want to create your custom vocabulary by
including all desired terms, as comma-separated values, within your
request. The other option for creating your custom vocabulary is to
save your entries in a text file and upload them to an Amazon S3
bucket, then specify the location of your file using the
VocabularyFileUri parameter.
Note that if you include Phrases in your request, you cannot use
VocabularyFileUri; you must choose one or the other.
Each language has a character set that contains all allowed characters for that specific language. If you use unsupported characters, your custom vocabulary filter request fails. Refer to Character Sets for Custom Vocabularies to get the character set for your language.
1251 1252 1253 1254 1255 1256 1257 1258 1259 1260 1261 |
# File 'lib/aws-sdk-transcribeservice/types.rb', line 1251 class CreateVocabularyRequest < Struct.new( :vocabulary_name, :language_code, :phrases, :vocabulary_file_uri, :tags, :data_access_role_arn, :encryption_configuration) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
Adds one or more custom tags, each in the form of a key:value pair, to a new custom vocabulary at the time you create this new custom vocabulary.
To learn more about using tags with Amazon Transcribe, refer to Tagging resources.
1251 1252 1253 1254 1255 1256 1257 1258 1259 1260 1261 |
# File 'lib/aws-sdk-transcribeservice/types.rb', line 1251 class CreateVocabularyRequest < Struct.new( :vocabulary_name, :language_code, :phrases, :vocabulary_file_uri, :tags, :data_access_role_arn, :encryption_configuration) SENSITIVE = [] include Aws::Structure end |
#vocabulary_file_uri ⇒ String
The Amazon S3 location of the text file that contains your custom vocabulary. The URI must be located in the same Amazon Web Services Region as the resource you're calling.
Here's an example URI path:
s3://DOC-EXAMPLE-BUCKET/my-vocab-file.txt
Note that if you include VocabularyFileUri in your request, you
cannot use the Phrases flag; you must choose one or the other.
1251 1252 1253 1254 1255 1256 1257 1258 1259 1260 1261 |
# File 'lib/aws-sdk-transcribeservice/types.rb', line 1251 class CreateVocabularyRequest < Struct.new( :vocabulary_name, :language_code, :phrases, :vocabulary_file_uri, :tags, :data_access_role_arn, :encryption_configuration) SENSITIVE = [] include Aws::Structure end |
#vocabulary_name ⇒ String
A unique name, chosen by you, for your new custom vocabulary.
This name is case sensitive, cannot contain spaces, and must be
unique within an Amazon Web Services account. If you try to create a
new custom vocabulary with the same name as an existing custom
vocabulary, you get a ConflictException error.
1251 1252 1253 1254 1255 1256 1257 1258 1259 1260 1261 |
# File 'lib/aws-sdk-transcribeservice/types.rb', line 1251 class CreateVocabularyRequest < Struct.new( :vocabulary_name, :language_code, :phrases, :vocabulary_file_uri, :tags, :data_access_role_arn, :encryption_configuration) SENSITIVE = [] include Aws::Structure end |