Class: Aws::TranscribeService::Types::EncryptionConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::TranscribeService::Types::EncryptionConfiguration
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-transcribeservice/types.rb
Overview
Encryption configuration for the invocation
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#kms_encryption_context ⇒ Hash<String,String>
A map of plain text, non-secret key:value pairs, known as encryption context pairs, that provide an added layer of security for your data.
-
#kms_key ⇒ String
The Amazon Resource Name (ARN) of the KMS key you want to use to encrypt your resource artifacts.
Instance Attribute Details
#kms_encryption_context ⇒ Hash<String,String>
A map of plain text, non-secret key:value pairs, known as encryption context pairs, that provide an added layer of security for your data. For more information, see KMS encryption context.
1496 1497 1498 1499 1500 1501 |
# File 'lib/aws-sdk-transcribeservice/types.rb', line 1496 class EncryptionConfiguration < Struct.new( :kms_encryption_context, :kms_key) SENSITIVE = [] include Aws::Structure end |
#kms_key ⇒ String
The Amazon Resource Name (ARN) of the KMS key you want to use to encrypt your resource artifacts. Only full KMS key ARN format is supported.
KMS key ARNs have the format
arn:partition:kms:region:account:key/key-id. For example:
arn:aws:kms:us-west-2:111122223333:key/1234abcd-12ab-34cd-56ef-1234567890ab.
For more information, see KMS key ARNs.
1496 1497 1498 1499 1500 1501 |
# File 'lib/aws-sdk-transcribeservice/types.rb', line 1496 class EncryptionConfiguration < Struct.new( :kms_encryption_context, :kms_key) SENSITIVE = [] include Aws::Structure end |