Class: Aws::TranscribeService::Types::GetVocabularyResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::TranscribeService::Types::GetVocabularyResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-transcribeservice/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#data_access_role_arn ⇒ String
The Amazon Resource Name (ARN) of the IAM role used to access the Amazon S3 bucket that contains your input files and, if applicable, the KMS key specified in
EncryptionConfiguration. -
#download_uri ⇒ String
The Amazon S3 location where the custom vocabulary is stored; use this URI to view or download the custom vocabulary.
-
#encryption_configuration ⇒ Types::EncryptionConfiguration
The encryption configuration used for your custom vocabulary.
-
#failure_reason ⇒ String
If
VocabularyStateisFAILED,FailureReasoncontains information about why the custom vocabulary request failed. -
#language_code ⇒ String
The language code you selected for your custom vocabulary.
-
#last_modified_time ⇒ Time
The date and time the specified custom vocabulary was last modified.
-
#vocabulary_name ⇒ String
The name of the custom vocabulary you requested information about.
-
#vocabulary_state ⇒ String
The processing state of your custom vocabulary.
Instance Attribute Details
#data_access_role_arn ⇒ String
The Amazon Resource Name (ARN) of the IAM role used to access the
Amazon S3 bucket that contains your input files and, if applicable,
the KMS key specified in EncryptionConfiguration.
1822 1823 1824 1825 1826 1827 1828 1829 1830 1831 1832 1833 |
# File 'lib/aws-sdk-transcribeservice/types.rb', line 1822 class GetVocabularyResponse < Struct.new( :vocabulary_name, :language_code, :vocabulary_state, :last_modified_time, :failure_reason, :download_uri, :data_access_role_arn, :encryption_configuration) SENSITIVE = [] include Aws::Structure end |
#download_uri ⇒ String
The Amazon S3 location where the custom vocabulary is stored; use this URI to view or download the custom vocabulary.
1822 1823 1824 1825 1826 1827 1828 1829 1830 1831 1832 1833 |
# File 'lib/aws-sdk-transcribeservice/types.rb', line 1822 class GetVocabularyResponse < Struct.new( :vocabulary_name, :language_code, :vocabulary_state, :last_modified_time, :failure_reason, :download_uri, :data_access_role_arn, :encryption_configuration) SENSITIVE = [] include Aws::Structure end |
#encryption_configuration ⇒ Types::EncryptionConfiguration
The encryption configuration used for your custom vocabulary.
1822 1823 1824 1825 1826 1827 1828 1829 1830 1831 1832 1833 |
# File 'lib/aws-sdk-transcribeservice/types.rb', line 1822 class GetVocabularyResponse < Struct.new( :vocabulary_name, :language_code, :vocabulary_state, :last_modified_time, :failure_reason, :download_uri, :data_access_role_arn, :encryption_configuration) SENSITIVE = [] include Aws::Structure end |
#failure_reason ⇒ String
If VocabularyState is FAILED, FailureReason contains
information about why the custom vocabulary request failed. See
also: Common Errors.
1822 1823 1824 1825 1826 1827 1828 1829 1830 1831 1832 1833 |
# File 'lib/aws-sdk-transcribeservice/types.rb', line 1822 class GetVocabularyResponse < Struct.new( :vocabulary_name, :language_code, :vocabulary_state, :last_modified_time, :failure_reason, :download_uri, :data_access_role_arn, :encryption_configuration) SENSITIVE = [] include Aws::Structure end |
#language_code ⇒ String
The language code you selected for your custom vocabulary.
1822 1823 1824 1825 1826 1827 1828 1829 1830 1831 1832 1833 |
# File 'lib/aws-sdk-transcribeservice/types.rb', line 1822 class GetVocabularyResponse < Struct.new( :vocabulary_name, :language_code, :vocabulary_state, :last_modified_time, :failure_reason, :download_uri, :data_access_role_arn, :encryption_configuration) SENSITIVE = [] include Aws::Structure end |
#last_modified_time ⇒ Time
The date and time the specified custom vocabulary was last modified.
Timestamps are in the format YYYY-MM-DD'T'HH:MM:SS.SSSSSS-UTC. For
example, 2022-05-04T12:32:58.761000-07:00 represents 12:32 PM
UTC-7 on May 4, 2022.
1822 1823 1824 1825 1826 1827 1828 1829 1830 1831 1832 1833 |
# File 'lib/aws-sdk-transcribeservice/types.rb', line 1822 class GetVocabularyResponse < Struct.new( :vocabulary_name, :language_code, :vocabulary_state, :last_modified_time, :failure_reason, :download_uri, :data_access_role_arn, :encryption_configuration) SENSITIVE = [] include Aws::Structure end |
#vocabulary_name ⇒ String
The name of the custom vocabulary you requested information about.
1822 1823 1824 1825 1826 1827 1828 1829 1830 1831 1832 1833 |
# File 'lib/aws-sdk-transcribeservice/types.rb', line 1822 class GetVocabularyResponse < Struct.new( :vocabulary_name, :language_code, :vocabulary_state, :last_modified_time, :failure_reason, :download_uri, :data_access_role_arn, :encryption_configuration) SENSITIVE = [] include Aws::Structure end |
#vocabulary_state ⇒ String
The processing state of your custom vocabulary. If the state is
READY, you can use the custom vocabulary in a
StartTranscriptionJob request.
1822 1823 1824 1825 1826 1827 1828 1829 1830 1831 1832 1833 |
# File 'lib/aws-sdk-transcribeservice/types.rb', line 1822 class GetVocabularyResponse < Struct.new( :vocabulary_name, :language_code, :vocabulary_state, :last_modified_time, :failure_reason, :download_uri, :data_access_role_arn, :encryption_configuration) SENSITIVE = [] include Aws::Structure end |