Class: Aws::TranscribeService::Types::UpdateLanguageModelRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::TranscribeService::Types::UpdateLanguageModelRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-transcribeservice/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#data_access_role_arn ⇒ String
The Amazon Resource Name (ARN) of an IAM role.
-
#encryption_configuration ⇒ Types::EncryptionConfiguration
Specifies the new encryption configuration for your custom language model.
-
#model_name ⇒ String
The name of the custom language model you want to update.
Instance Attribute Details
#data_access_role_arn ⇒ String
The Amazon Resource Name (ARN) of an IAM role. If you include
EncryptionConfiguration in your request, this role must have
permissions to access the specified KMS key. If the role that you
specify doesn't have the appropriate permissions, your request
fails.
IAM role ARNs have the format
arn:partition:iam::account:role/role-name-with-path. For example:
arn:aws:iam::111122223333:role/Admin.
For more information, see IAM ARNs.
5824 5825 5826 5827 5828 5829 5830 |
# File 'lib/aws-sdk-transcribeservice/types.rb', line 5824 class UpdateLanguageModelRequest < Struct.new( :model_name, :data_access_role_arn, :encryption_configuration) SENSITIVE = [] include Aws::Structure end |
#encryption_configuration ⇒ Types::EncryptionConfiguration
Specifies the new encryption configuration for your custom language model. The model artifacts are re-encrypted in place using the specified KMS key or with an AWS-owned key if a key is not supplied.
5824 5825 5826 5827 5828 5829 5830 |
# File 'lib/aws-sdk-transcribeservice/types.rb', line 5824 class UpdateLanguageModelRequest < Struct.new( :model_name, :data_access_role_arn, :encryption_configuration) SENSITIVE = [] include Aws::Structure end |
#model_name ⇒ String
The name of the custom language model you want to update. Model names are case sensitive.
5824 5825 5826 5827 5828 5829 5830 |
# File 'lib/aws-sdk-transcribeservice/types.rb', line 5824 class UpdateLanguageModelRequest < Struct.new( :model_name, :data_access_role_arn, :encryption_configuration) SENSITIVE = [] include Aws::Structure end |