Class: Aws::TranscribeService::Types::UpdateLanguageModelResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::TranscribeService::Types::UpdateLanguageModelResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-transcribeservice/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#last_modified_time ⇒ Time
The date and time the specified custom language model was last modified.
-
#model_name ⇒ String
The name of the custom language model that was updated.
-
#model_status ⇒ String
The status of the specified custom language model.
Instance Attribute Details
#last_modified_time ⇒ Time
The date and time the specified custom language model was last modified.
5847 5848 5849 5850 5851 5852 5853 |
# File 'lib/aws-sdk-transcribeservice/types.rb', line 5847 class UpdateLanguageModelResponse < Struct.new( :model_name, :model_status, :last_modified_time) SENSITIVE = [] include Aws::Structure end |
#model_name ⇒ String
The name of the custom language model that was updated.
5847 5848 5849 5850 5851 5852 5853 |
# File 'lib/aws-sdk-transcribeservice/types.rb', line 5847 class UpdateLanguageModelResponse < Struct.new( :model_name, :model_status, :last_modified_time) SENSITIVE = [] include Aws::Structure end |
#model_status ⇒ String
The status of the specified custom language model.
5847 5848 5849 5850 5851 5852 5853 |
# File 'lib/aws-sdk-transcribeservice/types.rb', line 5847 class UpdateLanguageModelResponse < Struct.new( :model_name, :model_status, :last_modified_time) SENSITIVE = [] include Aws::Structure end |