Class: Aws::TranscribeService::Waiters::CallAnalyticsJobCompleted

Inherits:
Object
  • Object
show all
Defined in:
sig/waiters.rbs,
lib/aws-sdk-transcribeservice/waiters.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(options) ⇒ CallAnalyticsJobCompleted

Returns a new instance of CallAnalyticsJobCompleted.

Parameters:

  • options (Hash)

Options Hash (options):

  • :client (required, Client)
  • :max_attempts (Integer) — default: 180
  • :delay (Integer) — default: 10
  • :before_attempt (Proc)
  • :before_wait (Proc)


90
91
# File 'lib/aws-sdk-transcribeservice/waiters.rb', line 90

def initialize: (?client: Client, ?max_attempts: Integer, ?delay: Integer, ?before_attempt: Proc, ?before_wait: Proc) -> void
| (?Hash[Symbol, untyped]) -> void

Instance Attribute Details

#waiterObject (readonly)

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.



122
123
124
# File 'lib/aws-sdk-transcribeservice/waiters.rb', line 122

def waiter
  @waiter
end

Instance Method Details

#wait(params = {}) ⇒ Types::GetCallAnalyticsJobResponse

Returns a response object which responds to the following methods:

Options Hash (params):

  • :call_analytics_job_name (required, String)

    The name of the Call Analytics job you want information about. Job names are case sensitive.

Returns:



117
# File 'lib/aws-sdk-transcribeservice/waiters.rb', line 117

def wait: (