Class: Aws::TranscribeService::Waiters::CallAnalyticsJobCompleted
- Inherits:
-
Object
- Object
- Aws::TranscribeService::Waiters::CallAnalyticsJobCompleted
- Defined in:
- sig/waiters.rbs,
lib/aws-sdk-transcribeservice/waiters.rb
Instance Attribute Summary collapse
- #waiter ⇒ Object readonly private
Instance Method Summary collapse
-
#initialize(options) ⇒ CallAnalyticsJobCompleted
constructor
A new instance of CallAnalyticsJobCompleted.
-
#wait(params = {}) ⇒ Types::GetCallAnalyticsJobResponse
Returns a response object which responds to the following methods:.
Constructor Details
#initialize(options) ⇒ CallAnalyticsJobCompleted
Returns a new instance of CallAnalyticsJobCompleted.
90 91 |
# File 'lib/aws-sdk-transcribeservice/waiters.rb', line 90
def initialize: (?client: Client, ?max_attempts: Integer, ?delay: Integer, ?before_attempt: Proc, ?before_wait: Proc) -> void
| (?Hash[Symbol, untyped]) -> void
|
Instance Attribute Details
#waiter ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
122 123 124 |
# File 'lib/aws-sdk-transcribeservice/waiters.rb', line 122 def waiter @waiter end |
Instance Method Details
#wait(params = {}) ⇒ Types::GetCallAnalyticsJobResponse
Returns a response object which responds to the following methods:
- #call_analytics_job => Types::CallAnalyticsJob
117 |
# File 'lib/aws-sdk-transcribeservice/waiters.rb', line 117
def wait: (
|