Class: Aws::TranscribeService::Waiters::MedicalVocabularyReady
- Inherits:
-
Object
- Object
- Aws::TranscribeService::Waiters::MedicalVocabularyReady
- Defined in:
- lib/aws-sdk-transcribeservice/waiters.rb
Instance Attribute Summary collapse
- #waiter ⇒ Object readonly private
Instance Method Summary collapse
-
#initialize(options) ⇒ MedicalVocabularyReady
constructor
A new instance of MedicalVocabularyReady.
-
#wait(params = {}) ⇒ Types::GetMedicalVocabularyResponse
Returns a response object which responds to the following methods:.
Constructor Details
#initialize(options) ⇒ MedicalVocabularyReady
Returns a new instance of MedicalVocabularyReady.
266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 |
# File 'lib/aws-sdk-transcribeservice/waiters.rb', line 266 def initialize() @client = .fetch(:client) @waiter = Aws::Waiters::Waiter.new({ max_attempts: 180, delay: 10, poller: Aws::Waiters::Poller.new( operation_name: :get_medical_vocabulary, acceptors: [ { "state" => "success", "matcher" => "path", "argument" => "vocabulary_state", "expected" => "READY" }, { "state" => "failure", "matcher" => "path", "argument" => "vocabulary_state", "expected" => "FAILED" } ] ) }.merge()) end |
Instance Attribute Details
#waiter ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
298 299 300 |
# File 'lib/aws-sdk-transcribeservice/waiters.rb', line 298 def waiter @waiter end |
Instance Method Details
#wait(params = {}) ⇒ Types::GetMedicalVocabularyResponse
Returns a response object which responds to the following methods:
-
#vocabulary_name => String
-
#language_code => String
-
#vocabulary_state => String
-
#last_modified_time => Time
-
#failure_reason => String
-
#download_uri => String
293 294 295 |
# File 'lib/aws-sdk-transcribeservice/waiters.rb', line 293 def wait(params = {}) @waiter.wait(client: @client, params: params) end |